@@ -130,8 +130,8 @@ To start applications with it you can use the L<morbo> script.
   $ morbo myapp.pl
   Server available at http://127.0.0.1:3000.
 
-Optional modules L<EV>, L<IO::Socket::IP>, L<IO::Socket::SSL> and
-L<Net::Rendezvous::Publish> are supported transparently and used if installed.
+Optional modules L<EV> (4.0+), L<IO::Socket::IP> (0.16+) and
+L<IO::Socket::SSL> (1.75+) are supported transparently and used if installed.
 Individual features can also be disabled with the C<MOJO_NO_IPV6> and
 C<MOJO_NO_TLS> environment variables.
 
